@@ -1,4 +1,4 @@
-use ginepro::LoadBalancedChannelBuilder;
+use ginepro::LoadBalancedChannel;
 use tonic::transport::Certificate;
 use tonic::transport::ClientTlsConfig;
 
@@ -16,7 +16,7 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
 
     let tls = ClientTlsConfig::new().ca_certificate(ca);
 
-    let channel = LoadBalancedChannelBuilder::new_with_service(("localhost", 5000_u16))
+    let channel = LoadBalancedChannel::builder(("localhost", 5000_u16))
         .await?
         .with_tls(tls)
         .dns_probe_interval(std::time::Duration::from_secs(5))
